@@ -19,6 +19,7 @@ def pressure_field(positions,frequencies,
                z_range = [-1,1],
                point_density = 100,
                directivity_distance = 1000,
+               num_directivity_points = 10000,
                method = "Monopole Addition",
                dimensions = 2,
                directivity_only = False,
@@ -88,7 +89,6 @@ def pressure_field(positions,frequencies,
         
         # Getting the directivity at a given distance. Default is 1000 meters away
         if not dimensions == 1:
-            num_directivity_points = 1000
             directivity_points, theta = define_arc(directivity_distance,num_directivity_points)
             directivity = np.abs(rayleigh(positions,areas,velocities,phases,directivity_points,frequencies,time))
             directivity = directivity / np.max(directivity)
@@ -103,7 +103,6 @@ def pressure_field(positions,frequencies,
         
         # Getting the directivity at a given distance. Default is 1000 meters away
         if not dimensions == 1:
-            num_directivity_points = 1000
             directivity_points, theta = define_arc(directivity_distance,num_directivity_points)
             directivity = np.abs(monopole_field(positions,frequencies,strengths,phases,directivity_points,time))
             directivity = directivity / np.max(directivity)
